# Laughbag


## Features

### Request and Response

* custom response class

### Routing

### Handler

* class handler

* function handler supporting allowed methods

### Test Client


### Template 

### Exception Handler

### Static Files

### Middleware


## ToDo


* Cookies / Session

* Database

* File Upload

* Error Handler

* Rate Limit

* Websocket
